@@ -8,7 +8,7 @@
 #        .
 #          .
 #
-#	SCCS: @(#)Expression.pm	1.44 03/30/15 18:29:00
+#	SCCS: @(#)Expression.pm	1.45 04/11/15 00:37:10
 #
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself. You must preserve this entire copyright
@@ -50,7 +50,7 @@ use vars qw/
 	$Version
 );
 
-our $VERSION = "1.44";
+our $VERSION = "1.45";
 
 # Fundamental to this is a tree of nodes.
 # Nodes are hashes with members:
@@ -146,6 +146,9 @@ my %InFuns = map { $_ => 1} qw/ abs aindex count defined int join localtime mkti
 # Inbuilt functions that must be given a L value
 my %InFunLV = map { $_ => 1} qw / defined pop push shift unshift /;
 
+# Escape chars recognised:
+my %escapes = ( n => "\n", r => "\r", t => "\t", '\\' => '\\' );
+
 # Default error output function
 sub PrintError {
 	my $self = shift;
@@ -273,9 +276,11 @@ sub ParseString {
 			$newt->{type} = 'num';	# Used in debug/tree-print
 			$operlast = 0;
 		} # Match string bounded by ' or "
-		elsif($expr =~ /^(['"])/ and $expr =~ s/^$1([^$1]*)$1//) {
+		elsif($expr =~ /^(['"])/ and $expr =~ s/^($1)([^$1]*)$1//) {
 			$newt->{oper} = 'const';
-			$newt->{val} = $1;
+			$newt->{val} = $2;
+			# Double quoted: understand some escapes:
+			$newt->{val} =~ s/\\([nrt\\]|x[\da-fA-F]{2})/length($1) == 1 ? $escapes{$1} : (chr hex '0'.$1)/ge if($1 eq '"');
 			$newt->{type} = 'str';
 			$operlast = 0;
 		} elsif($expr =~ s/^}//) {
@@ -1349,8 +1354,18 @@ A previous version of this module allowed more syntaxes.
 
 =head2 Literals
 
-Literals may be: integers, floating point in the form nn.nn, strings bounded by
-matching singe or double quotes. Escapes are not looked for in literal strings.
+Literals may be: integers, floating point in the forms nn.nn and with an exponent eg
+(123.4, 1.234e2, 1.234e+2).
+Strings are bounded by matching single C<'> or double quotes C<">.
+In strings surrounded by double quotes the following escapes will be recognised:
+
+	\n	newline
+	\r	carriage return
+	\t	tab
+	\\	\
+	\xXX	character with hex value XX. Eg: \x0A \x3b
+
+A backslash followed by anything else is left as is - ie the backslash will remain.
 
 =head2 Operators and precedence
 
@@ -1521,7 +1536,7 @@ Alain D D Williams <addw@phcomp.co.uk>
 
 =head2 Copyright and Version
 
-Version "1.44", this is available as: $Math::Expression::Version.
+Version "1.45", this is available as: $Math::Expression::Version.
 
 Copyright (c) 2003, 2015 Parliament Hill Computers Ltd/Alain D D Williams. All rights reserved.
 This program is free software; you can redistribute it and/or modify it
